@@ -32,6 +32,9 @@ class DictCaster:
     def get_keys(self) -> set[Hashable]:
         return set(itertools.chain(*[item.get_keys() for item in self.items]))
 
+    def get_str_keys(self) -> set[str]:
+        return {key for key in self.get_keys() if isinstance(key, str)}
+
     def _reinit_groupings(self) -> None:
         for grouping in set(self._item_to_grouping.values()):
             grouping.reinit()
